surrealcs_
kernel
0.4.0
Module allocator
Module Items
Structs
In crate surrealcs_
kernel
Module
surrealcs_kernel
::
allocator
source
·
[
−
]
An allocator for mapping an index to a value T.
Structs

Allocator
An allocator for mapping an index to a value T.