Module surrealcs_kernel::logging
source · Expand description
Defines the message types and the way in which actors handle messages to construct logs.
Modules
- Defines the handling and creation of messages for logging.
Defines the message types and the way in which actors handle messages to construct logs.