pub fn log_client_reader_message(message: &WrappedServerMessage)Expand description
Logs a transaction message that the client reader has received.
Arguments
message: the transaction message that the client reader has received
pub fn log_client_reader_message(message: &WrappedServerMessage)Logs a transaction message that the client reader has received.
message: the transaction message that the client reader has received