pub struct WrappedRouterMessage {
pub message: RouterMessage,
pub tx: Sender<RouterMessage>,
}Expand description
The messsage wrapper to enable returning a response to the sender.
Fields
message: The message to be sent to the routertx: the sender to send the response back to the initial sender from the router actor
Fields
message: RouterMessagetx: Sender<RouterMessage>Auto Trait Implementations
impl Freeze for WrappedRouterMessage
impl !RefUnwindSafe for WrappedRouterMessage
impl Send for WrappedRouterMessage
impl Sync for WrappedRouterMessage
impl Unpin for WrappedRouterMessage
impl !UnwindSafe for WrappedRouterMessage