Module bincode_processes

Module bincode_processes 

Defines the serialization and deserialization of messages using bincode.

Modules

message
Defines the functions performing serialization and deserialization of messages using bincode.