Module surrealcs_kernel::messages::server

source ·
defines the messages for the server.

Modules

  • The interface for the server message.
  • The key value operations that can be performed on the key value store.
  • The wrapper for the server message to be transferred between client and server.