Module surrealcs_kernel::messages::server::wrapper

source ·
The wrapper for the server message to be transferred between client and server.

Notes

No unit testing has been assigned to this module as it is a simple wrapper around the server message. There is no functionality to test.

Structs

  • A server message wrapped in meta data around the message so the key value data can be processed and returned by the server.