Module utils

Module utils 

Defines functions and macros that can be utilized across the kernel and other programs using the kernel.

Modules

generic
Houses utils that do not have a home yet.
log_error
Defines the utils around logging errors.