Module surrealcs_kernel::logging::messages
source · Expand description
Defines the handling and creation of messages for logging.
Modules
- Defines the functions that log recieving messages for actors in the client.
- Defines the functions that log recieving messages for actors in the server.
- Defines structs around logging for connections
- Defines structs around logging for transactions