Module surrealcs_kernel::utils

source ·
Defines functions and macros that can be utilized across the kernel and other programs using the kernel.

Modules

  • Houses utils that do not have a home yet.
  • Defines the utils around logging errors.